"""Add creation workflows for imported products.

Revision ID: ab8d805d27b3
Revises: 3b73ee683cec
Create Date: 2024-04-19 16:21:07.304696

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = 'ab8d805d27b3'
down_revision = '3b73ee683cec'
branch_labels = None
depends_on = None


from orchestrator.migrations.helpers import create_workflow, delete_workflow

new_workflows = [
    {
        "name": "create_imported_site",
        "target": "CREATE",
        "description": "Import Site",
        "product_type": "ImportedSite"
    },
    {
        "name": "create_imported_router",
        "target": "CREATE",
        "description": "Import router",
        "product_type": "ImportedRouter"
    },
    {
        "name": "create_imported_iptrunk",
        "target": "CREATE",
        "description": "Import iptrunk",
        "product_type": "ImportedIptrunk"
    },
    {
        "name": "create_imported_super_pop_switch",
        "target": "CREATE",
        "description": "Import Super PoP switch",
        "product_type": "ImportedSuperPopSwitch"
    },
    {
        "name": "create_imported_office_router",
        "target": "CREATE",
        "description": "Import office router",
        "product_type": "ImportedOfficeRouter"
    }
]


def upgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        create_workflow(conn, workflow)


def downgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        delete_workflow(conn, workflow["name"])
