"""A modification workflow for migrating an ImportedEdgePort to an EdgePort subscription."""

from orchestrator.targets import Target
from orchestrator.types import State, UUIDstr
from orchestrator.workflow import StepList, done, init, step, workflow
from orchestrator.workflows.steps import resync, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form

from gso.products import EdgePort, ImportedEdgePort, ProductName
from gso.services.subscriptions import get_product_id_by_name


@step("Create new Edge Port subscription")
def import_edge_port_subscription(subscription_id: UUIDstr) -> State:
    """Take an ImportedEdgePort subscription, and turn it into an EdgePort subscription."""
    old_edge_port = ImportedEdgePort.from_subscription(subscription_id)
    new_subscription_id = get_product_id_by_name(ProductName.EDGE_PORT)
    new_subscription = EdgePort.from_other_product(old_edge_port, new_subscription_id)  # type: ignore[arg-type]

    return {"subscription": new_subscription}


@workflow("Import Edge Port", target=Target.MODIFY, initial_input_form=wrap_modify_initial_input_form(None))
def import_edge_port() -> StepList:
    """Modify an ImportedEdgePort subscription into an EdgePort subscription to complete the import."""
    return (
        init >> store_process_subscription(Target.MODIFY) >> unsync >> import_edge_port_subscription >> resync >> done
    )
