from unittest.mock import patch

import pytest

from gso.products import EdgePort
from test.services.conftest import MockedNetboxClient
from test.workflows import (
    assert_complete,
    assert_lso_interaction_success,
    extract_state,
    run_workflow,
)


@pytest.mark.workflow()
@patch("gso.workflows.edge_port.terminate_edge_port.execute_playbook")
@patch("gso.services.netbox_client.NetboxClient.delete_interface")
@patch("gso.services.netbox_client.NetboxClient.free_interface")
def test_successful_edge_port_termination(
    mocked_free_interface,
    mocked_delete_interface,
    mock_execute_playbook,
    edge_port_subscription_factory,
    faker,
    data_config_filename,
):
    #  Set up mock return values
    subscription_id = edge_port_subscription_factory()
    mocked_netbox = MockedNetboxClient()
    mocked_delete_interface.return_value = mocked_netbox.delete_interface()
    mocked_free_interface.return_value = mocked_netbox.free_interface()

    #  Run workflow
    initial_data = [
        {"subscription_id": subscription_id},
        {
            "tt_number": faker.tt_number(),
        },
    ]
    result, process_stat, step_log = run_workflow("terminate_edge_port", initial_data)

    for _ in range(2):
        result, step_log = assert_lso_interaction_success(result, process_stat, step_log)

    assert_complete(result)

    # Check NetboxClient calls
    assert mocked_delete_interface.call_count == 1  # Delete the lag
    assert mocked_free_interface.call_count == 2  # Free interfaces attached to the lag which is 2

    state = extract_state(result)
    subscription_id = state["subscription_id"]
    subscription = EdgePort.from_subscription(subscription_id)

    assert subscription.status == "terminated"
    assert mock_execute_playbook.call_count == 2
